@@ -192,6 +192,9 @@ use File::Find
                 s/ESMF//;# Break first ESMF string
                 s/ESMF/ ESMF/;# Break it into 2 fields
                 s/([^ ]*) ([^ ]*)/$2/; # Get rid of the 1st field
+                s/ESMC//;# Break first ESMC string
+                s/ESMC/ ESMC/;# Break it into 2 fields
+                s/([^ ]*) ([^ ]*)/$2/; # Get rid of the 1st field
                 s/\./ /; # Break it into 2 fields
                 s/([^ ]*) ([^ ]*)/$1.Log\n/; # Get rid of the 2nd field
         }
@@ -225,7 +228,7 @@ use File::Find
                 @Log_files=grep (/STest/, @tmp_Log_files);
                 #Sort the list of Log files.
                 @Log_files = sort (@Log_files);
-                # Find the Log fles that are in the st_ex_files
+                # Find the Log fles that are in the st_st_files
                 foreach $file ( @st_st_files) {
                                 push @Log_st_files, grep (/$file/, @Log_files);
                 }
@@ -279,6 +282,12 @@ use File::Find
                         foreach $file ( @pass_tests) {
                                 push @pass_st_files, grep (/$file.F90/, @act_st_files);
                         }
+                        foreach $file ( @pass_tests) {
+                                push @pass_st_files, grep (/$file.C/, @act_st_files);
+                        }
+                        foreach $file ( @pass_tests) {
+                                push @pass_st_files, grep (/$file.c/, @act_st_files);
+                        }
 			if (!$SUMMARY) { # Print only if full output requested
                 		print "\n\n";
                         	if ($pass_count == 1) {
@@ -345,7 +354,7 @@ use File::Find
                                 s/\.stdout//; # Delete stdout
                         }
 
-                        # Find the system test executable files that are in the st_ex_files
+                        # Find the system test executable files that are in the st_x_files
                         foreach $file ( @st_st_files) {
                                         push @stdout_st_files, grep (/$file/, @st_x_files);
                         }
