@@ -1,7 +1,7 @@
 // $Id$
 //
 // Earth System Modeling Framework
-// Copyright (c) 2002-2023, University Corporation for Atmospheric Research,
+// Copyright (c) 2002-2024, University Corporation for Atmospheric Research,
 // Massachusetts Institute of Technology, Geophysical Fluid Dynamics
 // Laboratory, University of Michigan, National Centers for Environmental
 // Prediction, Los Alamos National Laboratory, Argonne National Laboratory,
@@ -63,7 +63,7 @@ namespace ESMCI {
   template<typename SIT, typename DIT> class SparseMatrix;
 
   // class definitions
-  
+
 //TODO: Figure out how to have code use correct SeqIndex structure automatic.
 //TODO: For now just hard-code the use of one or the other via CPP definition.
 #define SeqIndexTensor SeqIndex
@@ -173,7 +173,7 @@ namespace ESMCI {
     // larrayList and larrayBaseAddrList hold the PET-local DEs in the first
     // localDe many entries. Then, up to vasLocalDeCount are the DEs that
     // are in the same VAS, and up to ssiLocalDeCount are the DEs that are
-    // in the same SSI. 
+    // in the same SSI.
     // Without VAS DE sharing, vasLocalDeCount==localDeCount.
     // Without SSI DE sharing, ssiLocalDeCount==vasLocalDeCount.
     LocalArray **larrayList;          // [ssiLocalDeCount] localDeCount first
@@ -191,6 +191,8 @@ namespace ESMCI {
     int *totalUBound;                 // [redDimCount*ssiLocalDeCount]
     int tensorCount;                  // number of tensor dimensions
     int tensorElementCount;           // number of tensor elements per element
+    int replicatedDimCount;           // number of replicated dimensions
+                                      // (i.e., dimensions where distgridToArrayMap[i] == 0)
     int *undistLBound;                // [tensorCount]
     int *undistUBound;                // [tensorCount]
     int *distgridToArrayMap;          // [dimCount] - entries are basis 1
@@ -201,13 +203,6 @@ namespace ESMCI {
                                       // entry of 0 indicates replicated dim
                                       // distr. Array dims as 1, 2, 3, .. only
     int *contiguousFlag;              // [ssiLocalDeCount]
-    int *exclusiveElementCountPDe;    // [deCount] number of elements in
-                                      // exclusive region only considering
-                                      // DistGrid dims that are associated with
-                                      // the Array dims.
-                                      // Multiply with tensorElementCount to get
-                                      // total number of elements in exclusive
-                                      // Array region.
     int *totalElementCountPLocalDe;   // [ssiLocalDeCount] number of elements in
                                       // total region only considering
                                       // DistGrid dims that are associated with
@@ -262,6 +257,7 @@ namespace ESMCI {
       totalLBound = NULL;
       totalUBound = NULL;
       tensorCount = 0;
+      replicatedDimCount = 0;
       undistLBound = NULL;
       undistUBound = NULL;
       distgridToArrayMap = NULL;
@@ -269,7 +265,6 @@ namespace ESMCI {
       distgridToPackedArrayMap = NULL;
       contiguousFlag = NULL;
       tensorElementCount = 0;
-      exclusiveElementCountPDe = NULL;
       totalElementCountPLocalDe = NULL;
       sizeSuperUndist = NULL;
       sizeDist = NULL;
@@ -300,6 +295,7 @@ namespace ESMCI {
       totalLBound = NULL;
       totalUBound = NULL;
       tensorCount = 0;
+      replicatedDimCount = 0;
       undistLBound = NULL;
       undistUBound = NULL;
       distgridToArrayMap = NULL;
@@ -307,7 +303,6 @@ namespace ESMCI {
       distgridToPackedArrayMap = NULL;
       contiguousFlag = NULL;
       tensorElementCount = 0;
-      exclusiveElementCountPDe = NULL;
       totalElementCountPLocalDe = NULL;
       sizeSuperUndist = NULL;
       sizeDist = NULL;
@@ -324,12 +319,12 @@ namespace ESMCI {
    private:
     Array(ESMC_TypeKind_Flag typekind, int rank, LocalArray **larrayList,
       VM::memhandle *mh, int vasLocalDeCount, int ssiLocalDeCount,
-      int *localDeToDeMap, DistGrid *distgrid, bool distgridCreator, 
+      int *localDeToDeMap, DistGrid *distgrid, bool distgridCreator,
       int *exclusiveLBound, int *exclusiveUBound, int *computationalLBound,
       int *computationalUBound, int *totalLBound, int *totalUBound,
-      int tensorCount, int tensorElementCount, int *undistLBoundArray,
-      int *undistUBoundArray, int *distgridToArrayMapArray,
-      int *arrayToDistGridMapArray, int *distgridToPackedArrayMapArray, 
+      int tensorCount, int tensorElementCount, int replicatedDimCount,
+      int *undistLBoundArray, int *undistUBoundArray, int *distgridToArrayMapArray,
+      int *arrayToDistGridMapArray, int *distgridToPackedArrayMapArray,
       ESMC_IndexFlag indexflagArg, int *rc,
       VM *vm=NULL); // allow specific VM instead default
    public:
@@ -363,7 +358,8 @@ namespace ESMCI {
       InterArray<int> *undistLBoundArg, InterArray<int> *undistUBoundArg,
       int *rc, VM *vm=NULL);
     static Array *create(Array *array, DataCopyFlag copyflag,
-      DELayout *delayout=NULL, int rmLeadingTensors=0, int *rc=NULL);
+      DELayout *delayout=NULL, InterArray<int> *trailingTensorSlice=NULL,
+      int rmLeadingTensors=0, int *rc=NULL);
     static Array *create(Array *array, bool rmTensorFlag, int *rc=NULL);
     static int destroy(Array **array, bool noGarbage=false);
     // data copy()
@@ -384,10 +380,9 @@ namespace ESMCI {
     const int *getTotalLBound()             const {return totalLBound;}
     const int *getTotalUBound()             const {return totalUBound;}
     int getTensorCount()                    const {return tensorCount;}
+    int getReplicatedDimCount()             const {return replicatedDimCount;}
     const int *getUndistLBound()            const {return undistLBound;}
     const int *getUndistUBound()            const {return undistUBound;}
-    const int *getExclusiveElementCountPDe()const
-      {return exclusiveElementCountPDe;}
     const int *getTotalElementCountPLocalDe()const
       {return totalElementCountPLocalDe;}
     int getTensorElementCount()             const {return tensorElementCount;}
@@ -433,6 +428,8 @@ namespace ESMCI {
          const std::string &convention, const std::string &purpose,
          bool *overwrite, ESMC_FileStatus_Flag *status,
          int *timeslice, ESMC_IOFmt_Flag *iofmt);
+    void log(std::string prefix,
+      ESMC_LogMsgType_Flag msgType=ESMC_LOGMSG_INFO, bool deepFlag=false)const;
     int print() const;
     int sync();
     int validate() const;
