@@ -1,6 +1,6 @@
 // $Id$
 // Earth System Modeling Framework
-// Copyright (c) 2002-2023, University Corporation for Atmospheric Research, 
+// Copyright (c) 2002-2024, University Corporation for Atmospheric Research, 
 // Massachusetts Institute of Technology, Geophysical Fluid Dynamics 
 // Laboratory, University of Michigan, National Centers for Environmental 
 // Prediction, Los Alamos National Laboratory, Argonne National Laboratory, 
@@ -21,6 +21,7 @@
 #include <Mesh/include/Legacy/ESMCI_MCoord.h>
 #include <Mesh/include/Legacy/ESMCI_Sintdnode.h>
 #include <Mesh/include/Legacy/ESMCI_SM.h>
+#include <Mesh/include/ESMCI_XGridUtil.h>
 
 #include <vector>
 
@@ -53,7 +54,7 @@ namespace ESMCI {
 #endif
 
   void calc_2nd_order_weights_2D_3D_sph(const MeshObj *src_elem, MEField<> *src_cfield, MEField<> *src_mask_field, 
-                                           std::vector<const MeshObj *> dst_elems, MEField<> *dst_cfield, MEField<> * dst_mask_field, MEField<> * dst_frac2_field,
+                                        std::vector<const MeshObj *> dst_elems, MEField<> *dst_cfield, MEField<> * dst_mask_field, MEField<> * dst_frac2_field, XGRID_USE xgrid_use, 
                                            double *src_elem_area,
                                            std::vector<int> *valid, 
                                            std::vector<HC_WGHT> *wgts, 
@@ -64,7 +65,7 @@ namespace ESMCI {
                                            );
 
   void calc_2nd_order_weights_2D_2D_cart(const MeshObj *src_elem, MEField<> *src_cfield, MEField<> *src_mask_field, 
-                                           std::vector<const MeshObj *> dst_elems, MEField<> *dst_cfield, MEField<> * dst_mask_field, MEField<> * dst_frac2_field,
+                                           std::vector<const MeshObj *> dst_elems, MEField<> *dst_cfield, MEField<> * dst_mask_field, MEField<> * dst_frac2_field, XGRID_USE xgrid_use, 
                                            double *src_elem_area,
                                            std::vector<int> *valid, 
                                            std::vector<HC_WGHT> *wgts, 
