@@ -1,10 +1,10 @@
 // $Id$
 //
 // Earth System Modeling Framework
-// Copyright (c) 2002-2023, University Corporation for Atmospheric Research, 
-// Massachusetts Institute of Technology, Geophysical Fluid Dynamics 
-// Laboratory, University of Michigan, National Centers for Environmental 
-// Prediction, Los Alamos National Laboratory, Argonne National Laboratory, 
+// Copyright (c) 2002-2024, University Corporation for Atmospheric Research,
+// Massachusetts Institute of Technology, Geophysical Fluid Dynamics
+// Laboratory, University of Michigan, National Centers for Environmental
+// Prediction, Los Alamos National Laboratory, Argonne National Laboratory,
 // NASA Goddard Space Flight Center.
 // Licensed under the University of Illinois-NCSA License.
 //
@@ -306,26 +306,37 @@ class VMK{
     int mypet;          // PET id of this instance
     esmf_pthread_t mypthid;  // my pthread id
     // pet -> core mapping
-    int npets;      // number of PETs in this VMK
+    int npets;      // number of PETs in this VMK all SSI
     int *lpid;      // local pid (equal to rank in local MPI context)
     int *pid;       // pid (equal to rank in MPI_COMM_WORLD)
     int *tid;       // thread index
     int *ncpet;     // number of cores this pet references
-    int *nadevs;    // number of accelerator devices accessible from this pet
+    int *nadevs;//TODO: to be removed // number of accelerator devices accessible from this pet
     int **cid;      // core id of the cores this pet references
+    // SSI
     int ssiCount;   // number of single system images in this VMK
     int ssiMinPetCount;   // minimum PETs on a single system image
     int ssiMaxPetCount;   // maximum PETs on a single system image
     int ssiLocalPetCount; // number of PETs on the same SSI as localPet (incl.)
+    int ssiLocalPet;      // id of local PET in the local SSI
     int *ssiLocalPetList; // PETs that are on the same SSI as localPet (incl.)
+    // SSI DEV
+    int devCount;   // number of devices associated with this VMK all SSI
+    int ssiLocalDevCount;// number of devices associated with this VMK on local SSI
+    int *ssiLocalDevList;// list of SSI-local device indices associated with this VMK
+                    // Use this index to make local association calls (e.g. via
+                    // acc_set_device_num() or omp_set_default_device()), and
+                    // to look up global device index in ssidevs array.
+    // SSI NUMA
+    int ssiLocalNumaCount; // number of NUMA modes on the same SSI as localPet (incl.)
+    int *ssiLocalNumaList; // NUMA nodes
     // general information about this VMK
-    int mpionly;    // 0: there is multi-threading, 1: MPI-only
-    bool threadsflag; // threaded or none-threaded VM
+    bool mpionly;         // false: there is multi-threading, true: MPI-only
+    bool threadsflag;     // threaded or none-threaded VM
     // MPI Communicator handles
     MPI_Comm mpi_c;     // communicator across the entire VM
-#if !(defined ESMF_NO_MPI3 || defined ESMF_MPIUNI)
     MPI_Comm mpi_c_ssi; // communicator holding PETs on the same SSI
-#endif
+    MPI_Comm mpi_c_ssi_roots; // communicator holding root PETs on each SSI
     // Shared mutex and thread_finish variables. These are pointers that will be
     // pointing to shared memory variables between different thread-instances of
     // the VMK object.
@@ -355,9 +366,14 @@ class VMK{
     // static info of physical machine
     static int nssiid;  // total number of single system image ids
     static int ncores;  // total number of cores in the physical machine
+    static int ndevs;   // total number of devices in physical machine
+    static int ndevsSSI;// total number of devices in physical machine on SSI
+    //TODO: consider using SSI shared memory for the following arrays
     static int *cpuid;  // cpuid associated with certain core (multi-core cpus)
-    static int *ssiid;  // single system image id to which this core belongs
-    static int *ssipe;  // PE id on the SSI on which this PE resides
+    static int *ssiid;  // single system image on which a certain core resides
+    static int *ssipe;  // ssi-local PE id of a certain core
+    static int *ssidevs;// list of global device ids for all ssi-local devices
+    // begin of execution reference time
     static double wtime0; // the MPI WTime at the very beginning of execution
   public:
     // Declaration of static data members - Definitions are in the header of
@@ -388,6 +404,10 @@ class VMK{
     static int argc_mpich;
     static char *argv_mpich_store[100];
     static char **argv_mpich;
+    // NVML support
+    static bool nvmlEnabled;     // NVML support enabled or disabled
+    // NUMA support
+    static bool numaEnabled;     // NUMA support enabled or disabled
 
   // methods
   private:
@@ -426,6 +446,9 @@ class VMK{
     static int checkPetList(int *petList, int count);
       // ensure there are no duplicate PETs listed
 
+    static int checkDevList(int *devList, int count);
+      // ensure there are no duplicate DEVs listed
+
     void print() const;
     void log(std::string prefix,
       ESMC_LogMsgType_Flag msgType=ESMC_LOGMSG_INFO)const;
@@ -459,7 +482,11 @@ class VMK{
     int getSsiMinPetCount() const {return ssiMinPetCount;}
     int getSsiMaxPetCount() const {return ssiMaxPetCount;}
     int getSsiLocalPetCount() const {return ssiLocalPetCount;}
+    int getSsiLocalPet() const {return ssiLocalPet;}
     const int *getSsiLocalPetList() const {return ssiLocalPetList;}
+    int getSsiLocalDevCount() const {return ssiLocalDevCount;}
+    const int *getSsiLocalDevList() const {return ssiLocalDevList;}
+    int getDevCount() const {return devCount;}
     esmf_pthread_t getLocalPthreadId() const {return mypthid;}
     static bool isPthreadsEnabled(){
 #ifdef ESMF_NO_PTHREADS
@@ -490,10 +517,19 @@ class VMK{
       return true;
 #endif
     }
-    static bool isSsiSharedMemoryEnabled();
-      //TODO: For now had to implement this method in the source file, because
-      //TODO: of the way the ESMF_NO_MPI3 macro is being determined.
-      //TODO: Move it into the VMKernel header once includes are fixed.
+    static bool isSsiSharedMemoryEnabled(){
+#if (MPI_VERSION >= 3) || (defined ESMF_MPIUNI)
+      return true;
+#else
+      return false;
+#endif
+    }
+    static bool isNvmlEnabled(){
+      return nvmlEnabled;
+    }
+    static bool isNumaEnabled(){
+      return numaEnabled;
+    }
 
 #define XSTR(X) STR(X)
 #define STR(X) #X
@@ -609,6 +645,8 @@ class VMKPlan{
     int npets;
     int nplist;       // number of PETs in petlist that participate
     int *petlist;     // keeping sequence of parent pets
+    int ndevlist;     // number of DEVs in devList
+    int *devlist;     // list of associated devices
     bool supportContributors;     // default: false
     bool eachChildPetOwnPthread;  // default: false
     int parentVMflag; // 0-create child VM, 1-run on parent VM
@@ -635,7 +673,7 @@ class VMKPlan{
     int openmpnumthreads; // -1 default: local peCount
 
   public:
-    VMKPlan();
+    VMKPlan(int _ndevlist=0, int *_devlist=NULL);
       // native constructor (sets communication preferences to defaults)
     ~VMKPlan();
       // native destructor
@@ -709,19 +747,22 @@ class VMKPlan{
 class ComPat{
  private:
   // pure virtual methods to be implemented by user
-     
+
   virtual int messageSize(int srcPet, int dstPet)                  const =0;
     // will be called on both sides, i.e. localPet==srcPet and localPet==dstPet
- 
+
   virtual void messagePrepare(int srcPet, int dstPet, char *buffer)const =0;
     // will be called only for localPet==srcPet
-  
+
+  virtual void messagePrepareSearch(VMK *vmk, int sendIndexOffset, int iiStart,
+    int iiEnd, std::vector<char *> &sendBuffer)                    const =0;
+
   virtual void messageProcess(int srcPet, int dstPet, char *buffer)      =0;
     // will be called only for localPet==dstPet
-  
+
   virtual void localPrepareAndProcess(int localPet)                      =0;
     // will be called for every localPet once
-  
+
  public:
   // communication patterns
   void totalExchange(VMK *vmk);
@@ -731,28 +772,28 @@ class ComPat{
 class ComPat2{
  private:
   // pure virtual methods to be implemented by user
-     
+
   virtual void handleLocal() =0;
     // called on every localPet exactly once, before any other method
 
   virtual void generateRequest(int responsePet,
     char* &requestBuffer, int &requestSize) =0;
     // called on every localPet for every responsePet != localPet
- 
+
   virtual void handleRequest(int requestPet,
     char *requestBuffer, int requestSize,
     char* &responseBuffer, int &responseSize)const =0;
     // called on every localPet for every requestPet != localPet
- 
+
   virtual void handleResponse(int responsePet,
     char const *responseBuffer, int responseSize)const =0;
     // called on every localPet for every responsePet != localPet
 
  public:
-     
+
   // communication patterns
   void totalExchange(VMK *vmk);
-  void selectiveExchange(VMK *vmk, std::vector<int>&responderPet, 
+  void selectiveExchange(VMK *vmk, std::vector<int>&responderPet,
     std::vector<int>&requesterPet);
 }; // ComPat2
 
