@@ -1,7 +1,7 @@
 // $Id$
 //
 // Earth System Modeling Framework
-// Copyright (c) 2002-2023, University Corporation for Atmospheric Research, 
+// Copyright (c) 2002-2024, University Corporation for Atmospheric Research, 
 // Massachusetts Institute of Technology, Geophysical Fluid Dynamics 
 // Laboratory, University of Michigan, National Centers for Environmental 
 // Prediction, Los Alamos National Laboratory, Argonne National Laboratory, 
@@ -262,7 +262,8 @@ int main(void){
   //NEX_UTest
   strcpy(name, "Create ESMC_GridComp object");
   strcpy(failMsg, "Did not return ESMF_SUCCESS");
-  gcomp = ESMC_GridCompCreate("gridded component in C", "comp.rc", clock, &rc);
+  gcomp = ESMC_GridCompCreate("gridded component in C", "comp.yaml", clock,
+    &rc);
   ESMC_Test((rc==ESMF_SUCCESS), name, failMsg, &result, __FILE__, __LINE__, 0);
   //----------------------------------------------------------------------------
   
@@ -327,8 +328,9 @@ int main(void){
   //NEX_UTest
   strcpy(name, "Create ESMC_GridComp object");
   strcpy(failMsg, "Did not return ESMF_SUCCESS");
-  gcomp = ESMC_GridCompCreate("gridded Component in C with Fortran registration",
-    "comp.rc", clock, &rc);
+  gcomp = ESMC_GridCompCreate(
+    "gridded Component in C with Fortran registration",
+    "comp.yaml", clock, &rc);
   ESMC_Test((rc==ESMF_SUCCESS), name, failMsg, &result, __FILE__, __LINE__, 0);
   //----------------------------------------------------------------------------
   
@@ -379,7 +381,8 @@ int main(void){
   //NEX_UTest
   strcpy(name, "Create ESMC_CplComp object");
   strcpy(failMsg, "Did not return ESMF_SUCCESS");
-  cplcomp = ESMC_CplCompCreate("coupler component in C", "comp.rc", clock, &rc);
+  cplcomp = ESMC_CplCompCreate("coupler component in C", "comp.yaml", clock,
+    &rc);
   ESMC_Test((rc==ESMF_SUCCESS), name, failMsg, &result, __FILE__, __LINE__, 0);
   //----------------------------------------------------------------------------
   
@@ -436,8 +439,9 @@ int main(void){
   //NEX_UTest
   strcpy(name, "Create ESMC_CplComp object");
   strcpy(failMsg, "Did not return ESMF_SUCCESS");
-  cplcomp = ESMC_CplCompCreate("coupler component in C with Fortran registration",
-    "comp.rc", clock, &rc);
+  cplcomp = ESMC_CplCompCreate(
+    "coupler component in C with Fortran registration",
+    "comp.yaml", clock, &rc);
   ESMC_Test((rc==ESMF_SUCCESS), name, failMsg, &result, __FILE__, __LINE__, 0);
   //----------------------------------------------------------------------------
   
